PaddingConfig class

Constructors

PaddingConfig({PaddingDirection direction = PaddingDirection.right, int? length, int? padToMultipleOf})
const

Properties

direction PaddingDirection
final
hashCode int
The hash code for this object.
no setterinherited
length int?
final
padToMultipleOf int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited