AbstractState<D extends AbstractDomain<D>> class

Abstract state mapping variables to their abstract values.

Constructors

AbstractState(D _defaultValue, [Map<String, D>? values])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, D>
no setter

Methods

getForJoin(String variable) → D
Returns the value for a variable during join operations. Returns BOTTOM if the variable is not defined in this state.
join(AbstractState<D> other) AbstractState<D>
narrow(AbstractState<D> other) AbstractState<D>
Narrows this state with another to recover precision after widening.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
widen(AbstractState<D> other) AbstractState<D>

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String variable) → D
Returns the value for a variable, or TOP if not defined.
operator []=(String variable, D value) → void