getForJoin method
Returns the value for a variable during join operations. Returns BOTTOM if the variable is not defined in this state.
Implementation
D getForJoin(String variable) => _values[variable] ?? _defaultValue.bottom;
Returns the value for a variable during join operations. Returns BOTTOM if the variable is not defined in this state.
D getForJoin(String variable) => _values[variable] ?? _defaultValue.bottom;