DebtTrend class
Represents the trend in technical debt over time.
Constructors
Properties
- costChange → double
-
Change in total cost.
no setter
- costChangePercent → double
-
Percentage change in cost.
no setter
- currentItemCount → int
-
Current item count.
final
- currentTotal → double
-
Current total cost.
final
- direction → String
-
Get trend direction as string.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDecreasing → bool
-
Whether debt is decreasing.
no setter
- isIncreasing → bool
-
Whether debt is increasing.
no setter
- itemCountChange → int
-
Change in item count.
no setter
- previousItemCount → int
-
Previous item count.
final
- previousTotal → double
-
Previous total cost.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → String
-
Unit of measurement.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited